@@ -7,17 +7,15 @@ source $PROJECT_SERVICEDIR/.bsfl
 # Variables
 SRC={{ src }}
 DEPLOY_DIR={{ deploy_dir }}
-SRC_STATIC_DIR={{ project_sourcedir }}/static
-PROJECT_STATICDIR={{ project_staticdir }}
 PROJECT_SOURCEDIR={{ project_sourcedir }}
+PROJECT_STATICDIR={{ project_staticdir }}
+SRC_STATIC_DIR=$PROJECT_SOURCEDIR/static
 
 # Change rights
 cmd_or_die "sudo chown -R $USER:$USER $DEPLOY_DIR"
 
 # Copy source directory to project source directory
-cmd_or_die "cp -r $SRC $PROJECT_SOURCEDIR"
-
-# Copy static in static dir
+cmd_or_die "cp -rf $SRC $PROJECT_SOURCEDIR"
 if [ -d $SRC_STATIC_DIR ]; then
-    cmd_or_die "cp -r $SRC_STATIC_DIR/* $PROJECT_STATICDIR"
+    cmd "sudo cp -r $SRC_STATIC_DIR/* $PROJECT_STATICDIR"
 fi
