@@ -9,10 +9,6 @@ PROGRAMM_NAME={{ project }}.{{ branch }}.celeryd
 DEPLOY_DIR={{ deploy_dir }}
 SUPERVISOR_CELERY_CONFPATH={{ supervisor_celery_confpath }}
 
-# Check supervisor installed
-check_program supervisord
-check_program supervisorctl
-
 msg_info "Create link to supervisor conf: $SUPERVISOR_CELERY_CONFPATH"
 cmd_or_die "sudo ln -sf $DEPLOY_DIR/deploy/supervisor.celeryd.conf $SUPERVISOR_CELERY_CONFPATH"
 
