@@ -7,10 +7,6 @@ source $PROJECT_SERVICEDIR/.bsfl
 PROGRAMM_NAME={{ project }}.{{ branch }}.celeryd
 SUPERVISOR_CELERY_CONFPATH={{ supervisor_celery_confpath }}
 
-# Check supervisor
-check_program supervisord
-check_program supervisorctl
-
 if [ -f $SUPERVISOR_CELERY_CONFPATH ]; then
     msg_info "Remove link to celeryd supervisor conf: $SUPERVISOR_CELERY_CONFPATH"
     cmd_or_die "sudo rm -rf $SUPERVISOR_CELERY_CONFPATH"
