@@ -9,9 +9,6 @@ CRON_PROJECTFILE={{ cron_projectfile }}
 CRON_PARSESCRIPT={{ deploy_dir }}/service/cron_parse.py
 
 
-# Check cron installed.
-check_program cron
-
 if [ -f $CRON_PROJECTFILE ]; then
     cmd_or_die "sudo python $CRON_PARSESCRIPT"
 fi
