@@ -14,8 +14,6 @@ DBNAME={{ dbname }}
 DBUSER={{ dbuser }}
 DBPASSWORD={{ dbpassword }}
 
-check_program psql
-
 if [ -z "$PGUSER" ] || [ -z $PGHOST ] || [ -z $PGPASSWORD ]; then
     # pass
     msg_warning "postgres some data not defined."
@@ -27,7 +25,7 @@ export PGPASSWORD=$PGPASSWORD
 export PGHOST=$PGHOST
 export PGPORT=$PGPORT
 
-SQL_CREATE_DB="create database $DBNAME with owner $DBUSER"
+SQL_CREATE_DB="create database $DBNAME with owner $DBUSER encoding 'UTF8'"
 SQL_CREATE_ROLE="create role $DBUSER with login password '$DBPASSWORD'"
 SQL_CHECK_DB="select count(1) from pg_catalog.pg_database where datname = '$DBNAME' "
 
